summaryrefslogtreecommitdiffstats
path: root/libkdegames/kchat.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/kchat.h')
-rw-r--r--libkdegames/kchat.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/libkdegames/kchat.h b/libkdegames/kchat.h
index 5eabb9d3..a28578c7 100644
--- a/libkdegames/kchat.h
+++ b/libkdegames/kchat.h
@@ -36,14 +36,15 @@ class KChatPrivate;
class KDE_EXPORT KChat : public KChatBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* @param parent The parent widget for this widget.
* @param twoPlayerGame If true the combo box where the player can
* choose to send to a single player or to all players will not be added
* as you will hardly need it in 2-player games.
**/
- KChat(TQWidget* parent, bool twoPlayerGame = false);
+ KChat(TQWidget* tqparent, bool twoPlayerGame = false);
virtual ~KChat();
@@ -36,14 +36,15 @@ class KChatPrivate;
public:
/**
- * @param parent The parent widget for this widget.
+ * @param tqparent The tqparent widget for this widget.
* @param twoPlayerGame If true the combo box where the player can
* choose to send to a single player or to all players will not be added